param([string] $name,[string] $ip,[string] $mask, [string] $gateway,[string] $dns1, [string] $dns2)

$erroractionpreference = 'stop';
trap [exception]{
	$outf = $MyInvocation.MyCommand.Definition + ".out";
	$_.Exception.Message > $outf
}
function CheckRuncode($runcode)
{
	$response = "";
	switch($runcode){
		  0 { $response = ""; break }
          1 {  $response = "Error " + $runcode + " : Successful completion, reboot required"; break}
          64 {  $response = "Error " + $runcode + " : Method not supported on this platform"; break}
          65 {  $response = "Error " + $runcode + " : Unknown failure"; break}
          66 {  $response = "Error " + $runcode + " : Invalid subnet mask"; break}
          67 {  $response = "Error " + $runcode + " : An error occurred while processing an instance that was returned"; break}
          68 {  $response = "Error " + $runcode + " : Invalid input parameter"; }
          69 {  $response = "Error " + $runcode + " : More than five gateways specified"; }
          70 {  $response = "Error " + $runcode + " : Invalid IP address"; }
          71 {  $response = "Error " + $runcode + " : Invalid gateway IP address"; }
          72 {  $response = "Error " + $runcode + " : An error occurred while accessing the registry for the requested information"; break}
          73 {  $response = "Error " + $runcode + " : Invalid domain name"; break}
          74 {  $response = "Error " + $runcode + " : Invalid host name"; }
          75 {  $response = "Error " + $runcode + " : No primary or secondary WINS server defined"; break}
          76 {  $response = "Error " + $runcode + " : Invalid file"; break}
          77 {  $response = "Error " + $runcode + " : Invalid system path"; break}
          78 {  $response = "Error " + $runcode + " : File copy failed"; break}
          79 {  $response = "Error " + $runcode + " : Invalid security parameter"; break}
          80 {  $response = "Error " + $runcode + " : Unable to configure TCP/IP service"; break}
          81 {  $response = "Error " + $runcode + " : Unable to configure DHCP service"; break}
          82 {  $response = "Error " + $runcode + " : Unable to renew DHCP lease"; break}
          83 {  $response = "Error " + $runcode + " : Unable to release DHCP lease"; break}
          84 {  $response = "Error " + $runcode + " : IP not enabled on adapter"; break}
          85 {  $response = "Error " + $runcode + " : IPX not enabled on adapter"; break}
          86 {  $response = "Error " + $runcode + " : Frame or network number bounds error"; break}
          87 {  $response = "Error " + $runcode + " : Invalid frame type"; break}
          88 {  $response = "Error " + $runcode + " : Invalid network number";break }
          89 {  $response = "Error " + $runcode + " : Duplicate network number"; break}
          90 {  $response = "Error " + $runcode + " : Parameter out of bounds"; break}
          91 {  $response = "Error " + $runcode + " : Access denied"; break}
          92 {  $response = "Error " + $runcode + " : Out of memory"; break}
          93 {  $response = "Error " + $runcode + " : Already exists"; break}
          94 {  $response = "Error " + $runcode + " : Path, file, or object not found"; break}
          95 {  $response = "Error " + $runcode + " : Unable to notify service"; break}
          96 {  $response = "Error " + $runcode + " : Unable to notify DNS service"; break}
          97 {  $response = "Error " + $runcode + " : Interface not configurable"; break}
          98 {  $response = "Error " + $runcode + " : Not all DHCP leases could be released or renewed"; break}
          100 {  $response = "Error " + $runcode + " : DHCP not enabled on adapter"; break}
          default { "Error " + $runcode + " : Unknown error code"; break}
	}
    if($response -ne "") { throw $response }
}

if( $name.StartsWith("#") )
{	
	$i =  $name -replace "#"
	$adapters = Get-WmiObject Win32_NetworkAdapter -Filter 'NetEnabled=True' 
	$na = $adapters | Select-Object -Index $i
	
	if($na -eq $null) { 
		$msg= 'No enabled network adapter found at index ' + $i +  '. List of adapters enabled: ' + $adapters;
		throw $msg
	}	
}
else
{
	$na = Get-WmiObject Win32_NetworkAdapter |  where-object { $_.NetConnectionId -eq $name } 
	if($na -eq $null) { 
		$msg= 'The network adapter ' + $name +  ' was not found';
		throw $msg
	}
}

$index = $na.DeviceID;
$naMO = Get-WmiObject Win32_NetworkAdapterConfiguration |  where-object { $_.Index -eq $index } 

if($ip -ne ""){
	$r = $naMO.EnableStatic($ip, $mask);
	CheckRuncode $r.ReturnValue
}

if($gateway -ne ""){
	$r =$naMO.SetGateways($gateway, 1);
	CheckRuncode $r.ReturnValue
}

if($dns1.Trim() -ne "" -and $dns2.Trim() -ne ""){
	$r =$naMO.SetDNSServerSearchOrder(@($dns1,$dns2));
	CheckRuncode $r.ReturnValue
} elseif($dns1 -ne ""){
		$r =$naMO.SetDNSServerSearchOrder(@($dns1));
		CheckRuncode $r.ReturnValue
}