#!/bin/bash

#########################################################################
#	ChangeIP.sh - Configure Network Adapter								#
#	Sintax: ChangeIP.sh -name [name] 									#
#						[-ip [ip] -mask [mask]]							#
#						[-gateway [gateway]]							#
#						[-dns1 [dns1]]									#
#						[-dns2 [dns2]]									#
#########################################################################

log="$0.out"
echo $log > /tmp/logout.txt
echo "ChangeIP.sh - Configure Network Adapter" > $log

# --- Checking arguments ------------------------------------------------

declare -i idx=2
for arg in "$@"
do
	next=${!idx}
	first=${next:0:1}
	if [ "$arg" == "-name" -a "$first" != "-" ]; then 
		name=$next
	fi
	if [ "$arg" == "-ip" -a "$first" != "-" ]; then 
		ip=$next
	fi
	if [ "$arg" == "-mask" -a "$first" != "-" ]; then 
		mask=$next
	fi
	if [ "$arg" == "-gateway" -a "$first" != "-" ]; then 
		gateway=$next
	fi
	if [ "$arg" == "-dns1" -a "$first" != "-" ]; then 
		dns1=$next
	fi
	if [ "$arg" == "-dns2" -a "$first" != "-" ]; then 
		dns2=$next
	fi

	idx=$idx+1
	
done

cfgfile="/etc/sysconfig/network-scripts/ifcfg-$name"

# --- Setting IP and Subnet Mask --------------------------------------

if [ -n "$name" -a -n "$ip" -a -n "$mask" ]; then
	# check if name start with # to reip by index 
	echo $name|cut -c1|grep "#"
	if [ $? -eq 0 ]
	then
		index=`echo $name|cut -c2-10`
		name=`ifconfig -a|grep "Ethernet"|head -$((index+1))|tail -1|cut -d" " -f1`
	fi

	echo "Setting Ip address to $ip and subnet mask to $mask on adapter $name" >> $log
	
	ifconfig $name $ip netmask $mask up &> $log
	ret=$?
	if [ $ret -ne 0 ]; then
		echo "Network card not found" >> $log
		exit $ret
	fi
	
	if [ -f "/etc/redhat-release" -a -f $cfgfile ]; then
		echo "Saving new ip and mask configuration" >> $log
		echo 'DEVICE="'$name'"' > $cfgfile
		echo 'ONBOOT="yes"' >> $cfgfile
		echo 'IPADDR='$ip >> $cfgfile
		echo 'NETMASK='$mask >> $cfgfile
		echo 'GATEWAY='$gateway >> $cfgfile
	fi
fi

# --- Setting Gateway -------------------------------------------------

if [ -n "$gateway" ]; then
	echo "Setting default gateway to $gateway" >> $log
	route add default gw $gateway >> $log
	ret=0
	if [ $ret -ne 0 ]; then
		exit $ret
	fi
fi


# --- Setting DNS Servers ---------------------------------------------

if [ -n "$dns1" -o -n "$dns2" ]; then
	
	if [ -n "$dns1" ]; then
		echo "Setting DNS to $dns1" >> $log
		echo "nameserver $dns1" > /etc/resolv.conf
	fi

	if [ -n "$dns2" ]; then
		echo "Setting DNS to $dns2" >> $log
		echo "nameserver $dns2" >> /etc/resolv.conf
	fi
fi

echo "Ok" >> $log
exit 0

